@@ -1,21 +1,22 @@
+# ===== plot.R =====
 #' Plot Method for Bias Diagnostic Results
 #'
 #' Plots the permutation distributions and observed test statistics for each fixed effect.
 #'
 #' @param x An object of class `"mixedbiastest"`.
+#' @param bins Integer, number of bins for the histograms (default 30).
 #' @param ... Additional arguments (currently not used).
-#' @return A \code{ggplot} object showing permutation distributions for all fixed effects.
+#' @return A \code{ggplot} object (returned invisibly) showing permutation distributions for all fixed effects.
 #' @method plot mixedbiastest
 #' @importFrom ggplot2 ggplot geom_histogram geom_vline facet_wrap labs theme_minimal geom_text aes
 #' @importFrom stats rnorm
 #' @importFrom rlang .data
 #' @export
-plot.mixedbiastest <- function(x, ...) {
+plot.mixedbiastest <- function(x, bins = 30, ...) {
   permutation_values_list <- x$permutation_values
   results <- x$results_table
   k_list_names <- results$Fixed_Effect
 
-  # Combine all permutation values into a single data frame
   df_list <- list()
   annotations <- data.frame(Fixed_Effect = character(), label = character(), stringsAsFactors = FALSE)
 
@@ -23,46 +24,45 @@ plot.mixedbiastest <- function(x, ...) {
     permutation_values <- permutation_values_list[[fe_name]]
     observed_value <- as.numeric(results$Bias_Estimate[results$Fixed_Effect == fe_name])
 
-    # Check if all permutation values are the same
+    if (length(permutation_values) == 0L) next
+
     if (length(unique(permutation_values)) == 1) {
-      # Indicate that permutation values are constant
       annotations <- rbind(annotations, data.frame(
         Fixed_Effect = fe_name,
-        label = "No variation in permutation values"
+        label = "No variation in permutation values",
+        stringsAsFactors = FALSE
       ))
-      permutation_values_current <- permutation_values
-    } else {
-      permutation_values_current <- permutation_values
     }
 
-    df <- data.frame(
-      PermutationValues = permutation_values_current,
+    df_list[[fe_name]] <- data.frame(
+      PermutationValues = permutation_values,
       Fixed_Effect = fe_name,
       Observed_Value = observed_value
     )
-    df_list[[fe_name]] <- df
+  }
+
+  # If nothing to plot, return quietly
+  if (!length(df_list)) {
+    message("No permutation values to plot.")
+    return(invisible(NULL))
   }
 
   combined_df <- do.call(rbind, df_list)
-
-  # Adjust the factor levels
   combined_df$Fixed_Effect <- factor(combined_df$Fixed_Effect, levels = k_list_names)
-  annotations$Fixed_Effect <- factor(annotations$Fixed_Effect, levels = k_list_names)
+  if (nrow(annotations) > 0) {
+    annotations$Fixed_Effect <- factor(annotations$Fixed_Effect, levels = k_list_names)
+  }
 
-
-
-  # Plot using facets
   p <- ggplot(combined_df, aes(x = .data$PermutationValues)) +
-    geom_histogram( fill = "lightblue", color = "black", na.rm = TRUE) +
+    geom_histogram(fill = "lightblue", color = "black", na.rm = TRUE, bins = bins) +
     geom_vline(aes(xintercept = .data$Observed_Value), color = "red",
-               linetype = "dashed", linewidth = 1) +
+               linetype = "dashed", size = 1) +
     facet_wrap(~ Fixed_Effect, scales = "free") +
     labs(title = "Bias Diagnostic for Fixed Effects",
          x = expression(hat(nu) %*% hat(eta)),
          y = "Frequency") +
     theme_minimal()
 
-  # Add annotations if any
   if (nrow(annotations) > 0) {
     p <- p + geom_text(
       data = annotations,
@@ -79,9 +79,6 @@ plot.mixedbiastest <- function(x, ...) {
     )
   }
 
-  # Suppress warnings and print the plot
   suppressWarnings(print(p))
-
-  # Optionally return the plot if desired
-  # return(p)
+  invisible(p)
 }
